pub struct ChildBuilder<'w, 's, 'a> { /* private fields */ }Expand description
Struct for building children onto an entity
Implementations
Sourceimpl<'w, 's, 'a> ChildBuilder<'w, 's, 'a>
impl<'w, 's, 'a> ChildBuilder<'w, 's, 'a>
Sourcepub fn spawn_bundle(
&mut self,
bundle: impl Bundle,
) -> EntityCommands<'w, 's, '_>
pub fn spawn_bundle( &mut self, bundle: impl Bundle, ) -> EntityCommands<'w, 's, '_>
Spawns an entity with the given bundle and inserts it into the children defined by the ChildBuilder
Sourcepub fn spawn(&mut self) -> EntityCommands<'w, 's, '_>
pub fn spawn(&mut self) -> EntityCommands<'w, 's, '_>
Spawns an Entity with no components and inserts it into the children defined by the ChildBuilder which adds the Parent component to it.
Sourcepub fn parent_entity(&self) -> Entity
pub fn parent_entity(&self) -> Entity
Returns the parent entity of this ChildBuilder
Sourcepub fn add_command<C>(&mut self, command: C) -> &mut ChildBuilder<'w, 's, 'a>where
C: Command + 'static,
pub fn add_command<C>(&mut self, command: C) -> &mut ChildBuilder<'w, 's, 'a>where
C: Command + 'static,
Adds a command to this ChildBuilder