IVec2

Struct IVec2 

#[repr(C)]
pub struct IVec2 { pub x: i32, pub y: i32, }
A 2-dimensional vector.

Fields

x: i32y: i32

Implementations

Source

impl IVec2

pub const ZERO: IVec2

All zeroes.

pub const ONE: IVec2

All ones.

pub const NEG_ONE: IVec2

All negative ones.

pub const X: IVec2

A unit-length vector pointing along the positive X axis.

pub const Y: IVec2

A unit-length vector pointing along the positive Y axis.

pub const NEG_X: IVec2

A unit-length vector pointing along the negative X axis.

pub const NEG_Y: IVec2

A unit-length vector pointing along the negative Y axis.

pub const AXES: [IVec2; 2]

The unit axes.

pub const fn new(x: i32, y: i32) -> IVec2

Creates a new vector.

pub const fn splat(v: i32) -> IVec2

Creates a vector with all elements set to v.

pub fn select(mask: BVec2, if_true: IVec2, if_false: IVec2) -> IVec2

Creates a vector from the elements in if_true and if_false, selecting which to use for each element of self.

A true element in the mask uses the corresponding element from if_true, and false uses the element from if_false.

pub const fn from_array(a: [i32; 2]) -> IVec2

Creates a new vector from an array.

pub const fn to_array(&self) -> [i32; 2]

[x, y]

pub const fn from_slice(slice: &[i32]) -> IVec2

Creates a vector from the first 2 values in slice.

Panics

Panics if slice is less than 2 elements long.

pub fn write_to_slice(self, slice: &mut [i32])

Writes the elements of self to the first 2 elements in slice.

Panics

Panics if slice is less than 2 elements long.

pub const fn extend(self, z: i32) -> IVec3

Creates a 3D vector from self and the given z value.

pub fn dot(self, rhs: IVec2) -> i32

Computes the dot product of self and rhs.

pub fn min(self, rhs: IVec2) -> IVec2

Returns a vector containing the minimum values for each element of self and rhs.

In other words this computes [self.x.min(rhs.x), self.y.min(rhs.y), ..].

pub fn max(self, rhs: IVec2) -> IVec2

Returns a vector containing the maximum values for each element of self and rhs.

In other words this computes [self.x.max(rhs.x), self.y.max(rhs.y), ..].

pub fn clamp(self, min: IVec2, max: IVec2) -> IVec2

Component-wise clamping of values, similar to i32::clamp.

Each element in min must be less-or-equal to the corresponding element in max.

Panics

Will panic if min is greater than max when glam_assert is enabled.

pub fn min_element(self) -> i32

Returns the horizontal minimum of self.

In other words this computes min(x, y, ..).

pub fn max_element(self) -> i32

Returns the horizontal maximum of self.

In other words this computes max(x, y, ..).

pub fn cmpeq(self, rhs: IVec2) -> BVec2

Returns a vector mask containing the result of a == comparison for each element of self and rhs.

In other words, this computes [self.x == rhs.x, self.y == rhs.y, ..] for all elements.

pub fn cmpne(self, rhs: IVec2) -> BVec2

Returns a vector mask containing the result of a != comparison for each element of self and rhs.

In other words this computes [self.x != rhs.x, self.y != rhs.y, ..] for all elements.

pub fn cmpge(self, rhs: IVec2) -> BVec2

Returns a vector mask containing the result of a >= comparison for each element of self and rhs.

In other words this computes [self.x >= rhs.x, self.y >= rhs.y, ..] for all elements.

pub fn cmpgt(self, rhs: IVec2) -> BVec2

Returns a vector mask containing the result of a > comparison for each element of self and rhs.

In other words this computes [self.x > rhs.x, self.y > rhs.y, ..] for all elements.

pub fn cmple(self, rhs: IVec2) -> BVec2

Returns a vector mask containing the result of a <= comparison for each element of self and rhs.

In other words this computes [self.x <= rhs.x, self.y <= rhs.y, ..] for all elements.

pub fn cmplt(self, rhs: IVec2) -> BVec2

Returns a vector mask containing the result of a < comparison for each element of self and rhs.

In other words this computes [self.x < rhs.x, self.y < rhs.y, ..] for all elements.

pub fn abs(self) -> IVec2

Returns a vector containing the absolute value of each element of self.

pub fn signum(self) -> IVec2

Returns a vector with elements representing the sign of self.

  • 1.0 if the number is positive, +0.0 or INFINITY
  • -1.0 if the number is negative, -0.0 or NEG_INFINITY
  • NAN if the number is NAN
pub fn perp(self) -> IVec2

Returns a vector that is equal to self rotated by 90 degrees.

pub fn perp_dot(self, rhs: IVec2) -> i32

The perpendicular dot product of self and rhs. Also known as the wedge product, 2D cross product, and determinant.

pub fn rotate(self, rhs: IVec2) -> IVec2

Returns rhs rotated by the angle of self. If self is normalized, then this just rotation. This is what you usually want. Otherwise, it will be like a rotation with a multiplication by self’s length.

pub fn as_vec2(&self) -> Vec2

Casts all elements of self to f32.

pub fn as_dvec2(&self) -> DVec2

Casts all elements of self to f64.

pub fn as_uvec2(&self) -> UVec2

Casts all elements of self to u32.