pub struct NonSend<'w, T>where
T: 'static,{ /* private fields */ }Expand description
Shared borrow of a non-Send resource.
Only Send resources may be accessed with the Res SystemParam. In case that the
resource does not implement Send, this SystemParam wrapper can be used. This will instruct
the scheduler to instead run the system on the main thread so that it doesn’t send the resource
over to another thread.
Panics
Panics when used as a SystemParameter if the resource does not exist.
Use Option<NonSend<T>> instead if the resource might not always exist.
Implementations