pub struct WorldChildBuilder<'w> { /* private fields */ }Expand description
Struct for adding children to an entity directly through the World for use in exclusive systems
Implementations
Sourceimpl<'w> WorldChildBuilder<'w>
impl<'w> WorldChildBuilder<'w>
Sourcepub fn spawn_bundle(
&mut self,
bundle: impl Bundle + Send + Sync + 'static,
) -> EntityMut<'_>
pub fn spawn_bundle( &mut self, bundle: impl Bundle + Send + Sync + 'static, ) -> EntityMut<'_>
Spawns an entity with the given bundle and inserts it into the children defined by the WorldChildBuilder
Sourcepub fn spawn(&mut self) -> EntityMut<'_>
pub fn spawn(&mut self) -> EntityMut<'_>
Spawns an Entity with no components and inserts it into the children defined by the WorldChildBuilder which adds the Parent component to it.
Sourcepub fn parent_entity(&self) -> Entity
pub fn parent_entity(&self) -> Entity
Returns the parent entity of this WorldChildBuilder