pub struct Entity { /* private fields */ }Expand description
Lightweight identifier of an entity.
The identifier is implemented using a generational index: a combination of an ID and a generation. This allows fast insertion after data removal in an array while minimizing loss of spatial locality.
Usage
This data type is returned by iterating a Query that has Entity as part of its query fetch type parameter (learn more).
It can also be obtained by calling EntityCommands::id or EntityMut::id.
fn setup(mut commands: Commands) {
// Calling `spawn` returns `EntityCommands`.
let entity = commands.spawn().id();
}
fn exclusive_system(world: &mut World) {
// Calling `spawn` returns `EntityMut`.
let entity = world.spawn().id();
}It can be used to refer to a specific entity to apply EntityCommands, or to call Query::get (or similar methods) to access its components.
fn dispose_expired_food(mut commands: Commands, query: Query<Entity, With<Expired>>) {
for food_entity in &query {
commands.entity(food_entity).despawn();
}
}Implementations
Sourceimpl Entity
impl Entity
Sourcepub fn from_raw(id: u32) -> Entity
pub fn from_raw(id: u32) -> Entity
Creates a new entity reference with the specified id and a generation of 0.
Note
Spawning a specific entity value is rarely the right choice. Most apps should favor
Commands::spawn. This method should generally
only be used for sharing entities across apps, and only when they have a scheme
worked out to share an ID space (which doesn’t happen by default).
In general, one should not try to synchronize the ECS by attempting to ensure that
Entity lines up between instances, but instead insert a secondary identifier as
a component.
There are still some use cases where it might be appropriate to use this function externally.
Examples
Initializing a collection (e.g. array or Vec) with a known size:
// Create a new array of size 10 and initialize it with (invalid) entities.
let mut entities: [Entity; 10] = [Entity::from_raw(0); 10];
// ... replace the entities with valid ones.Deriving Reflect for a component that has an Entity field:
#[derive(Reflect, Component)]
#[reflect(Component)]
pub struct MyStruct {
pub entity: Entity,
}
impl FromWorld for MyStruct {
fn from_world(_world: &mut World) -> Self {
Self {
entity: Entity::from_raw(u32::MAX),
}
}
}Sourcepub fn to_bits(self) -> u64
pub fn to_bits(self) -> u64
Convert to a form convenient for passing outside of rust.
Only useful for identifying entities within the same instance of an application. Do not use for serialization between runs.
No particular structure is guaranteed for the returned bits.
Sourcepub fn from_bits(bits: u64) -> Entity
pub fn from_bits(bits: u64) -> Entity
Reconstruct an Entity previously destructured with Entity::to_bits.
Only useful when applied to results from to_bits in the same instance of an application.
Sourcepub fn id(self) -> u32
pub fn id(self) -> u32
Return a transiently unique identifier.
No two simultaneously-live entities share the same ID, but dead entities’ IDs may collide with both live and dead entities. Useful for compactly representing entities within a specific snapshot of the world, such as when serializing.
Sourcepub fn generation(self) -> u32
pub fn generation(self) -> u32
Returns the generation of this Entity’s id. The generation is incremented each time an entity with a given id is despawned. This serves as a “count” of the number of times a given id has been reused (id, generation) pairs uniquely identify a given Entity.